@@ -18,13 +18,13 @@ from __future__ import annotations
 import argparse
 from argparse import ArgumentParser, Namespace
 import asyncio
+from collections.abc import AsyncIterator
 import contextlib
 import locale
 import logging
 import pathlib
 import re
 import sys
-from typing import AsyncIterator
 
 from zeroconf.asyncio import AsyncServiceBrowser, AsyncZeroconf
 
@@ -152,8 +152,10 @@ async def pair(args):
 
         discovery = await controller.async_find(args.device)
 
+        print(discovery.description)
+
         try:
-            finish_pairing = await discovery.start_pairing(args.alias)
+            finish_pairing = await discovery.async_start_pairing(args.alias)
         except HomeKitException as e:
             print(str(e))
             return False
